@@ -1,7 +1,4 @@
-from robot.api.parsing import (
-    ModelTransformer,
-    Token
-)
+from robot.api.parsing import ModelTransformer, Token
 from robotidy.decorators import check_start_end_line
 
 
@@ -13,24 +10,29 @@ class SplitTooLongLine(ModelTransformer):
     """
     Split too long lines.
     If any line in keyword call exceeds given length limit (configurable using ``line_length``, 120 by default) it will be
-    split::
+    split:
 
         Keyword With Longer Name    ${arg1}    ${arg2}    ${arg3}  # let's assume that arg2 is at 120 char
 
-    To::
+    To:
 
         Keyword With Longer Name    ${arg1}
         ...    ${arg2}    ${arg3}
 
-    Using ``split_on_every_arg`` flag (``False`` by default), you can force the formatter to put every argument in a new line::
+    Using ``split_on_every_arg`` flag (``False`` by default), you can force the formatter to put every argument in a
+    new line:
 
         Keyword With Longer Name
         ...    ${arg1}
         ...    ${arg2}
         ...    ${arg3}
 
-    Supports global formatting params: ``space_count``, ``--startline`` and ``--endline``.
+
+    Supports global formatting params: ``space_count``, ``separator``, ``--startline`` and ``--endline``.
+
+    See https://robotidy.readthedocs.io/en/latest/transformers/SplitTooLongLine.html for more examples.
     """
+
     def __init__(self, line_length: int = 120, split_on_every_arg: bool = False):
         super().__init__()
         self.line_length = line_length
@@ -49,7 +51,7 @@ class SplitTooLongLine(ModelTransformer):
             yield separator
 
     def split_keyword_call(self, node):
-        separator = Token(Token.SEPARATOR, self.formatting_config.space_count * ' ')
+        separator = Token(Token.SEPARATOR, self.formatting_config.separator)
         indent = node.tokens[0]
 
         assignment = node.get_tokens(Token.ASSIGN)
@@ -67,7 +69,7 @@ class SplitTooLongLine(ModelTransformer):
         # original comment, we need a lookback on the separator tokens.
         last_separator = None
 
-        rest = node.tokens[node.tokens.index(keyword) + 1:]
+        rest = node.tokens[node.tokens.index(keyword) + 1 :]
         for token in rest:
             if token.type == Token.SEPARATOR:
                 last_separator = token
@@ -80,14 +82,14 @@ class SplitTooLongLine(ModelTransformer):
                 #
                 # Notice the third value not starting with a hash - that's what this
                 # condition is about:
-                if not str(token).startswith('#'):
+                if not str(token).startswith("#"):
                     # -2 because -1 is the EOL
                     comments[-2].value += last_separator.value + token.value
                 else:
                     comments += [indent, token, EOL]
             elif token.type == Token.ARGUMENT:
-                if token.value == '':
-                    token.value = '${EMPTY}'
+                if token.value == "":
+                    token.value = "${EMPTY}"
                 if self.cols_remaining(line + [separator, token]) == 0:
                     line.append(EOL)
                     tail += line
@@ -118,4 +120,4 @@ class SplitTooLongLine(ModelTransformer):
         """Return the tokens from after the last EOL in the given list"""
         if EOL not in tokens:
             return tokens
-        return tokens[len(tokens) - tokens[::-1].index(EOL):]
+        return tokens[len(tokens) - tokens[::-1].index(EOL) :]
